@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.13 2000/12/22 16:36:31 hovinen Exp $ */
+/* $Id: gdict-applet.c,v 1.14 2001/02/15 22:00:26 jirka Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -12,8 +12,6 @@
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
-#else
-#  define PACKAGE "gdict"
 #endif
 
 #include <stdio.h>
@@ -307,7 +305,7 @@ gdict_applet_new ()
 
 	applet = g_malloc (sizeof(GDictApplet));
 
-    if ((applet->applet_widget = applet_widget_new(PACKAGE)) == NULL)
+    if ((applet->applet_widget = applet_widget_new("gdict")) == NULL)
         g_error(_("Cannot create applet!\n"));
 
     applet->vbox_widget = gtk_vbox_new(FALSE, 2);
