@@ -17,10 +17,9 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
  */
-
 #include "config.h"
 
-#include <glib.h>
+#include <gnome.h>
 
 #include <stdio.h>
 #include <fcntl.h>
@@ -164,14 +163,14 @@ format_ext2fs (GFloppy *floppy)
 	/* make the filesystem */
 	cmd = make_mke2fs_cmd (floppy);
 
-	fd_print (floppy, "MMaking filesystem on disk...");
+	fd_print (floppy, _("MMaking filesystem on disk..."));
 	rc = system (cmd);
 	if (rc > 3) {
-		fd_print (floppy, "EUnable to create filesystem correctly.");
+		fd_print (floppy, _("EUnable to create filesystem correctly."));
 		return -1;
 	}
 
-	fd_print (floppy, "MMaking filesystem on disk... Done");
+	fd_print (floppy, _("MMaking filesystem on disk... Done"));
 	if (floppy->quick_format)
 		fd_print (floppy, "P100");
 	
@@ -197,25 +196,25 @@ format_fat (GFloppy *floppy)
 
 	/* make the filesystem */
 	cmd = make_mformat_cmd (floppy);
-	fd_print (floppy, "MMaking filesystem on disk...");
+	fd_print (floppy, _("MMaking filesystem on disk..."));
 	rc = system (cmd);
 	if (rc != 0) {
-		fd_print (floppy, "EUnable to create filesystem.");
+		fd_print (floppy, _("EUnable to create filesystem."));
 		return -1;
 	}
-	fd_print (floppy, "MMaking filesystem on disk... Done");
+	fd_print (floppy, _("MMaking filesystem on disk... Done"));
 	if (floppy->quick_format)
 		fd_print (floppy, "P100");
 
 	/* check for bad_blocks */
 	if (!floppy->quick_format) {
-		fd_print (floppy, "MChecking for bad blocks... (this might take a while)"); 
+		fd_print (floppy, _("MChecking for bad blocks... (this might take a while)")); 
 		rc = system (g_strconcat (floppy->badblocks_cmd, " ", floppy->mdevice, NULL));
 		if (rc == 0) {
 			fd_print (floppy, "P100");
-			fd_print (floppy, "MChecking for bad blocks... Done");
+			fd_print (floppy, _("MChecking for bad blocks... Done"));
 		} else {
-			fd_print (floppy, "EUnable to create filesystem.");
+			fd_print (floppy, _("EUnable to create filesystem."));
 			return -1;
 		}
 	}
