@@ -179,7 +179,7 @@ main (int argc, char *argv[])
 	gfloppy_opts[0].descrip = _("The device to format");
 	gfloppy_opts[0].argDescrip = _("DEVICE");
 
-	bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
+	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
 
 	gnome_init_with_popt_table ("gfloppy", VERSION, argc, argv,
