@@ -19,13 +19,11 @@
 #define __DIALOG_H__
 
 
-gint gtt_delete_event(GtkWidget *w, gpointer *data);
-
 void new_dialog_ok(char *title, GtkWidget **dlg, GtkBox **vbox,
-		       char *s, GtkSignalFunc sigfunc, gpointer *data);
+		   char *s, GtkSignalFunc sigfunc, gpointer data);
 void new_dialog_ok_cancel(char *title, GtkWidget **dlg, GtkBox **vbox,
-			  char *s_ok, GtkSignalFunc sigfunc, gpointer *data,
-			  char *s_cancel, GtkSignalFunc c_sigfunc, gpointer *c_data);
+			  char *s_ok, GtkSignalFunc sigfunc, gpointer data,
+			  char *s_cancel, GtkSignalFunc c_sigfunc, gpointer c_data);
 void msgbox_ok(char *title, char *text, char *ok_text,
 	       GtkSignalFunc func);
 void msgbox_ok_cancel(char *title, char *text,
