@@ -27,13 +27,14 @@
 #include <glibtop/sysinfo.h>
 
 void fill_clist_from_glibtop_entry (GtkCList * list,
-                                    glibtop_entry * entry);
+                                    glibtop_entry * entry,
+                                    gint * width, gint * height);
 
 #endif
 
 void fill_clist(GtkCList * clist,
                 const gchar ** col1, const gchar ** col2, 
-                gint numitems);
+                gint numitems, gint * width, gint * height);
 
 GtkWidget * create_clist(const gchar * titles[]);
 
